from with_test import test, test_case, get_test_self, inject, inject_customized_must_method

__author__ = 'Colin Ji'
__versioninfo__ = (1, 2, 0)
__version__ = '.'.join(map(str, __versioninfo__))

__all__ = ['test', 'test_case', 'get_test_self', 'inject', 'inject_customized_must_method']



from distutils.core import setup

setup(
    name='minitest',
    version='1.2.0',
    author='Colin Ji',
    author_email='jichen3000@gmail.com',
    packages=['minitest'],
    url='https://pypi.python.org/pypi/minitest',
    description='Minitest is inspired by Ruby minispec.',
    long_description=open('README.txt').read(),
)
